.. currentmodule:: abjad.tools.scoretools

move_full_measure_tuplet_prolation_to_measure_time_signature
============================================================

.. autofunction:: move_full_measure_tuplet_prolation_to_measure_time_signature
